/*
    SDP Editor
    Copyright 2006 Martin Storsj

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Martin Storsj
    martin@martin.st
*/

#include "sdpeditappui.h"
#include "sdpeditdocument.h"
#include "sdpeditapplication.h"
#include <flogger.h>

CSdpEditDocument* CSdpEditDocument::NewL(CEikApplication& aApp) {
	CSdpEditDocument* self = NewLC(aApp);
	CleanupStack::Pop(self);
	return self;
}

CSdpEditDocument* CSdpEditDocument::NewLC(CEikApplication& aApp) {
	CSdpEditDocument* self = new(ELeave) CSdpEditDocument(aApp);
	CleanupStack::PushL(self);
	self->ConstructL();
	return self;
}

void CSdpEditDocument::ConstructL() {
}

CSdpEditDocument::CSdpEditDocument(CEikApplication& aApp) : CAknDocument(aApp) {
}

CSdpEditDocument::~CSdpEditDocument() {
}

CEikAppUi* CSdpEditDocument::CreateAppUiL() {
	return new(ELeave) CSdpEditAppUi(); 
}

CFileStore* CSdpEditDocument::OpenFileL(TBool aDoOpen, const TDesC& aFilename, RFs& aFs) {
	return CEikDocument::OpenFileL(aDoOpen, aFilename, aFs);
}

void CSdpEditDocument::StoreL(CStreamStore& aStore, CStreamDictionary& aStreamDic) const {
	CSdpEditAppUi *appUi = static_cast<CSdpEditAppUi*>(CEikonEnv::Static()->AppUi());
	RStoreWriteStream stream;
	TStreamId id = stream.CreateLC(aStore);
	stream.WriteInt32L(1);
	stream.WriteInt32L(appUi->iHandle);
	stream.WriteInt32L(appUi->iChannel);
	stream.CommitL();
	CleanupStack::PopAndDestroy();
	aStreamDic.AssignL(KUidSdpEditApp, id);
}

void CSdpEditDocument::RestoreL(const CStreamStore& aStore, const CStreamDictionary& aStreamDic) {
	CSdpEditAppUi *appUi = static_cast<CSdpEditAppUi*>(CEikonEnv::Static()->AppUi());
	if (appUi) {
	} else {
		RFileLogger::WriteFormat(_L("debug"), _L("sdpedit.txt"), EFileLoggingModeAppend, _L("no appUi yet"));
		return;
	}
	TStreamId id = aStreamDic.At(KUidSdpEditApp);
	RStoreReadStream stream;
	stream.OpenLC(aStore, id);
	TInt version = stream.ReadInt32L();
	if (version >= 1) {
		appUi->iHandle = stream.ReadInt32L();
		appUi->iChannel = stream.ReadInt32L();
	}
	CleanupStack::PopAndDestroy();
	SetChanged(EFalse);
}


